#!/bin/sh
# This script gets 2 params:
# 1 - destination file
# 2 - called program

if [ "$2" == "" ]; then echo "Not enough params!"; exit 1; fi

echo "#!/bin/sh" >$1
echo "if [ ! -x $2 ]; then" >>$1
echo "  echo ERROR: Unable to find $2. Please make sure it is installed." >>$1
echo "  exit 1" >>$1
echo "fi" >>$1
echo "PATH=/usr/lib/fjsdk/bin:\${PATH}" >>$1
echo "export PATH" >>$1
echo "exec $2 \$@" >>$1
chmod +x $1
